style "no_engine" 
{ 
  engine "" { } 
}
class "GokButton" style "no_engine"


style "style_button_normal"
{
	fg[PRELIGHT] = { 0.2, 0.2, 0.2 }
	fg[ACTIVE] = { 0, 0, 0 }
	fg[NORMAL] = { 1.0, 1.0, 1.0 }
	fg[INSENSITIVE] = { 0, 1.0, 1.0 }

	text[PRELIGHT] = { 0.2, 0.2, 0.2 }
	text[ACTIVE] = { 0, 0, 0 }
	text[NORMAL] = { 1.0, 1.0, 1.0 }
	text[INSENSITIVE] = { 0, 1.0, 1.0 }
  
	bg[PRELIGHT] = { 1.0, 0.7, .5 }
	bg[ACTIVE] = { 1.0, 1.0, 1.0 }
	bg[NORMAL] = { 0, 0, 1.0 }
	bg[INSENSITIVE] = { 1.0, 1.0, 1.0 }

	base[PRELIGHT] = { .7, .7, 1.0 }
	base[ACTIVE] = { 1.0, 1.0, 1.0 }
	base[NORMAL] = { 0, 0, 1.0 }
	base[INSENSITIVE] = { 1.0, 1.0, 1.0 }
}
widget "*StyleButtonNormal" style "style_button_normal"

style "style_text_normal"
{
	fg[PRELIGHT] = { 0.2, 0.2, 0.2 }
	fg[ACTIVE] = { 0, 0, 0 }
	fg[NORMAL] = { 1.0, 1.0, 1.0 }
	fg[INSENSITIVE] = { 0, 1.0, 1.0 }
  
	bg[PRELIGHT] = { .5, .5, 1.0 }
	bg[ACTIVE] = { .5, .5, 1.0 }
	bg[NORMAL] = { .5, .5, 1.0 }
	bg[INSENSITIVE] = { .5, .5, 1.0 }
}
widget "*StyleTextNormal" style "style_text_normal"

style "style_text_disabled"
{
	fg[PRELIGHT] = { 0.5, 0.5, 0.6 }
	fg[ACTIVE] = { 0.5, 0.5, 0.6 }
	fg[NORMAL] = { 0.6, 0.5, 0.6 }
	fg[INSENSITIVE] = { 0.5, 0.5, 0.6 }
  
	bg[PRELIGHT] = { 0.5, 0.5, 0.6 }
	bg[ACTIVE] = { 0.5, 0.5, 0.6 }
	bg[NORMAL] = { 0.5, 0.5, 0.6 }
	bg[INSENSITIVE] = { 0.5, 0.5, 0.6 }
}
widget "*StyleTextDisabled" style "style_text_disabled"

style "style_button_disabled"
{
	fg[PRELIGHT] = { 0.2, 0.2, 0.2 }
	fg[ACTIVE] = { 0.2, 0.2, 0.2 }
	fg[NORMAL] = { 0.2, 0.2, 0.2 }
	fg[INSENSITIVE] = { 0.5, 0.2, 0.2 }
  
	bg[PRELIGHT] = { 0.2, 0.2, 0.2 }
	bg[ACTIVE] = { 0.2, 0.2, 0.2 }
	bg[NORMAL] = { 0.2, 0.2, 0.2 }
	bg[INSENSITIVE] = { 0.2, 0.2, 0.2 }
}
widget "*StyleButtonDisabled" style "style_button_disabled"

style "style_button_branch"
{
	fg[PRELIGHT] = { 0, 0, .99 }
	fg[ACTIVE] = { 0, 0, .99 }
	fg[NORMAL] = { 0, 0, 0 }
	fg[INSENSITIVE] = { 0, 0, .99 }
  
	bg[PRELIGHT] = { 1.0, 0.7, .5 }
	bg[ACTIVE] = { 1.0, 1.0, 1.0 }
	bg[NORMAL] = { 0, .6, 1.0}
	bg[INSENSITIVE] = { 1.0, .1, 1.0 }
}
widget "*StyleButtonBranch" style "style_button_branch"

style "style_button_branchback"
{
	fg[PRELIGHT] = { 0, 0, .99 }
	fg[ACTIVE] = { 0, 0, .99 }
	fg[NORMAL] = { 0, 0, 00 }
	fg[INSENSITIVE] = { 0, 0, .99 }
  
	bg[PRELIGHT] = { 1.0, 0.7, .5 }
	bg[ACTIVE] = { 1.0, 1.0, 1.0 }
	bg[NORMAL] = { 0, .6, 1.0 }
	bg[INSENSITIVE] = { 1.0, 1.0, 1.0 }
}
widget "*StyleButtonBranchBack" style "style_button_branchback"

style "style_button_generalDynamic"
{
	fg[PRELIGHT] = { 0, 0, 1.0 }
	fg[ACTIVE] = { 1.0, 0, 0 }
	fg[NORMAL] = { 0, 0, .99 }
	fg[INSENSITIVE] = { .5, .3, .5 }
  
	bg[PRELIGHT] = { .7, 1.0, .5 }
	bg[ACTIVE] = { 1.0, 1.0, 1.0 }
	bg[NORMAL] = { .1, 0.2, .3 }
	bg[INSENSITIVE] = { 1.0, .4, .4 }
}
widget "*StyleButtonGeneralDynamic" style "style_button_generalDynamic"

style "style_button_branchmenus"
{
	fg[PRELIGHT] = { 0, 0, 1.0 }
	fg[ACTIVE] = { 1.0, 0, 0 }
	fg[NORMAL] = { 0, 0, .99 }
	fg[INSENSITIVE] = { .5, .3, .5 }
  
	bg[PRELIGHT] = { 1.0, 0.7, .5 }
	bg[ACTIVE] = { 1.0, 1.0, 1.0 }
	bg[NORMAL] = { .3, .1, .4 }
	bg[INSENSITIVE] = { .2, .8, 1.0 }
}
widget "*StyleButtonBranchMenus" style "style_button_branchmenus"

style "style_button_branchmenuitems"
{
	fg[PRELIGHT] = { 0, 0, 1.0 }
	fg[ACTIVE] = { 1.0, 0, 0 }
	fg[NORMAL] = { 0, 0, .99 }
	fg[INSENSITIVE] = { .5, .3, .5 }
  
	bg[PRELIGHT] = { 1.0, 0.7, .5 }
	bg[ACTIVE] = { 1.0, 1.0, 1.0 }
	bg[NORMAL] = { .4, .2, .5 }
	bg[INSENSITIVE] = { .2, .8, 1.0 }
}
widget "*StyleButtonBranchMenuItems" style "style_button_branchmenuitems"

style "style_button_menuitem"
{
	fg[PRELIGHT] = { 0, 0, 1.0 }
	fg[ACTIVE] = { 1.0, 0, 0 }
	fg[NORMAL] = { 0, 0, .99 }
	fg[INSENSITIVE] = { .5, .3, .5 }
  
	bg[PRELIGHT] = { 1.0, 0.7, .5 }
	bg[ACTIVE] = { 1.0, 1.0, 1.0 }
	bg[NORMAL] = { .5, .1, .6 }
	bg[INSENSITIVE] = { .6, .2, .2 }
}
widget "*StyleButtonMenuItem" style "style_button_menuitem"

style "style_button_branchtoolbars"
{
	fg[PRELIGHT] = { 0, 0, 1.0 }
	fg[ACTIVE] = { 1.0, 0, 0 }
	fg[NORMAL] = { 0, 0, .99 }
	fg[INSENSITIVE] = { .5, .3, .5 }
  
	bg[PRELIGHT] = { 1.0, 0.7, .5 }
	bg[ACTIVE] = { 1.0, 1.0, 1.0 }
	bg[NORMAL] = { .4, 0.1, .2 }
	bg[INSENSITIVE] = { 1.0, .4, .4 }
}
widget "*StyleButtonBranchToolbars" style "style_button_branchtoolbars"

style "style_button_settings"
{
	fg[PRELIGHT] = { 0, 0, 1.0 }
	fg[ACTIVE] = { 1.0, 0, 0 }
	fg[NORMAL] = { 0, 0, .99 }
	fg[INSENSITIVE] = { .5, .3, .5 }
  
	bg[PRELIGHT] = { 1.0, 0.7, .5 }
	bg[ACTIVE] = { 1.0, 1.0, 1.0 }
	bg[NORMAL] = { .8, .3, .1 }
	bg[INSENSITIVE] = { 1.0, .4, .4 }
}
widget "*StyleButtonSettings" style "style_button_settings"


style "style_button_branchgui"
{
	fg[PRELIGHT] = { 0, 0, 1.0 }
	fg[ACTIVE] = { 1.0, 0, 0 }
	fg[NORMAL] = { 0, 0, .99 }
	fg[INSENSITIVE] = { .5, .3, .5 }
  
	bg[PRELIGHT] = { 1.0, 0.7, .5 }
	bg[ACTIVE] = { 1.0, 1.0, 1.0 }
	bg[NORMAL] = { .2, 0.3, .1 }
	bg[INSENSITIVE] = { .6, .2, .2 }
}
widget "*StyleButtonBranchGUI" style "style_button_branchgui"

style "style_button_branchguiactions"
{
	fg[PRELIGHT] = { 0, 0, 1.0 }
	fg[ACTIVE] = { 1.0, 0, 0 }
	fg[NORMAL] = { 0, 0, .99 }
	fg[INSENSITIVE] = { .5, .3, .5 }
  
	bg[PRELIGHT] = { 1.0, 0.7, .5 }
	bg[ACTIVE] = { 1.0, 1.0, 1.0 }
	bg[NORMAL] = { .2, .4, .6 }
	bg[INSENSITIVE] = { .6, .2, .2 }
}
widget "*StyleButtonBranchGuiActions" style "style_button_branchguiactions"

style "style_button_branchpageselection"
{
	fg[PRELIGHT] = { 0, 0, 1.0 }
	fg[ACTIVE] = { 1.0, 0, 0 }
	fg[NORMAL] = { 0, 0, .99 }
	fg[INSENSITIVE] = { .5, .3, .5 }
  
	bg[PRELIGHT] = { 1.0, 0.9, .5 }
	bg[ACTIVE] = { 1.0, 1.0, 1.0 }
	bg[NORMAL] = { .2, .6, .55 }
	bg[INSENSITIVE] = { .6, .2, .2 }
}
widget "*StyleButtonBranchPageSelection" style "style_button_branchpageselection"

style "style_button_select"
{
	fg[PRELIGHT] = { 0.0, 0.0, 1.0 }
	fg[ACTIVE] = { 1.0, 0.0, 0.0 }
	fg[NORMAL] = { 0, 0, 0 }
	fg[INSENSITIVE] = { .5, .3, .5 }

	bg[PRELIGHT] = { 0.85, 0.7, 0.5 }
	bg[ACTIVE] = { 0.7, 0.4, 0.5 }
	bg[NORMAL] = { 0.85, 0.7, 0.4 }
	bg[INSENSITIVE] = { .6, .2, .2 }
}
widget "*StyleButtonSelect" style "style_button_select"

style "style_button_wordcomplete"
{
	fg[PRELIGHT] = { 0, 0, 1.0 }
	fg[ACTIVE] = { 1.0, 0, 0 }
	fg[NORMAL] = { 0, 0, .99 }
	fg[INSENSITIVE] = { .5, .3, .5 }
  
	bg[PRELIGHT] = { 1.0, 0.7, .5 }
	bg[ACTIVE] = { .7, .1, .8 }
	bg[NORMAL] = { .6, .6, 0.9 }
	bg[INSENSITIVE] = { 1.0, .4, .4 }
}
widget "*StyleButtonWordComplete" style "style_button_wordcomplete"
